```{include} ../README.md
:end-line: -6
```

```{toctree}
:hidden:
:maxdepth: 2

Home <self>
installation
usage
autoapi/miniav/index
contributing
```


```{toctree}
:caption: External Links
PyPI <https://pypi.org/project/miniav/>
Github <https://github.com/uwsbel/miniav>
```

